@@ -4,9 +4,8 @@ use strict;
 
 use vars qw($VERSION);
 
-$VERSION = '0.03';
+$VERSION = '0.04';
 
-#use DateTime 0.08;
 use DateTime::Duration;
 use DateTime::Locale;
 use Params::Validate qw/validate SCALAR OBJECT/;
@@ -108,6 +107,7 @@ sub locale { $_[0]->{locale} }
 sub is_leap_year {
     my $self = shift;
     my $year = $self->{year};
+    $year++ if $year < 0;
     if ($year % 4 != 3 or ($year % 100 == 27 and $year % 400 != 127)) {
         return 0;
     } else {
@@ -291,12 +291,13 @@ sub utc_rd_values {
     return if $self->is_imaginary;
 
     my ($year, $month, $day) = @{$self}{qw/year month day/};
+    $year++ if $year < 0;
 
     my $cyear = $year;
     $cyear++ if $month > 6;
     $day++ if $month > 11;
 
-    my $rd = 683984 +                   # 7 September 1873 = 28 Phalle 0
+    my $rd = 683984 +                   # 7 September 1873 = 28 Phalle '0'
              ($year-1) * 365 +          # normal years: 365 real days
              _floor( .25 * $cyear) -    # leap years
              _floor(($cyear+72)/100) +  # century years
@@ -377,6 +378,11 @@ sub _rd2ymd {
         $y ++;
     }
 
+    # There is no year 0
+    if ($y <= 0) {
+        $y--;
+    }
+
     return $y, $m, $d;
 }
 
@@ -433,6 +439,8 @@ sub add_duration {
 
     my %deltas = $dur->deltas;
 
+    $self->{year}++ if $self->{year} < 0;
+
     $self->{day} += $deltas{days} if $deltas{days};
     $self->{month} += $deltas{months} if $deltas{months};
 
@@ -444,13 +452,19 @@ sub add_duration {
         $self->{year} += _floor(($self->{month}-1)/13);
         $self->{month} %= 13;
     }
+
+    $self->{year}-- if $self->{year} <= 0;
+
     return $self;
 }
 
 sub subtract_datetime {
     my ($self, $dt) = @_;
 
-    my $days_diff = ($self->year  - $dt->year ) * 377 +
+    my ($syear, $dyear) = ($self->year, $dt->year);
+    $_ < 0 and $_++ for $syear, $dyear;
+
+    my $days_diff = ($syear       - $dyear    ) * 377 +
                     ($self->month - $dt->month) * 29 +
                     ($self->day   - $dt->day  );
     return DateTime::Duration->new( days => $days_diff );
@@ -486,401 +500,405 @@ sub compare
 my @feasts;
 
 sub feast {
-    return $feasts[ $_[0]->day_of_year_0 ];
+    return $feasts[ $_[0]->day_of_year_0 ][1];
+}
+
+sub type_of_feast {
+    return $feasts[ $_[0]->day_of_year_0 ][0];
 }
 
 # Feasts from
 # http://perso.wanadoo.fr/mexiqueculture/nouvelles6-latumba.htm
-@feasts = split /\n+/, <<EOF;
-Nativit d'Alfred Jarry
-St Ptyx, silentiaire (Abolition de)
-St Phnix, solipsiste et St Hyx, factotum
-St Lucien de Samosate, voyageur
-St Bardamu, voyageur
-Ste Vrola, assistante sociale
-St Alambic, abstracteur
-Absinthe, ci-devant St Alfred
-Descente du St Esprit (de Vin)
-Dilution
-Ste Pure, sportswoman
-Vide
-St Canterel, l'illuminateur
-St Sophrotatos l'Armnien, pataphysicien
-thernit
-St Ibicrate le Gomtre, pataphysicien
-Cphalorgie
-Fltes de Pan
-Stes Grues, ophiophiles
-Ste Mlusine, souillarde de cuisine
-St Venceslas, duc
-Emmanuel Dieu
-Ste Varia-Miriam, amphibie
-Sts Rakirs et Rastrons, porte-ctelettes
-Nativit de Sa Magnificence Opach
-St Joseb, notaire  la mode de Bretagne
-Stes Gigolette et Gaufrette, dogaresses
-Xylostomie
-Le Jet Musical
+@feasts = map [/(.) (.+)/], split /\n+/, <<EOF;
+1 Nativit d'Alfred Jarry
+4 St Ptyx, silentiaire (Abolition de)
+4 St Phnix, solipsiste et St Hyx, factotum
+4 St Lucien de Samosate, voyageur
+4 St Bardamu, voyageur
+4 Ste Vrola, assistante sociale
+4 St Alambic, abstracteur
+3 Absinthe, ci-devant St Alfred
+4 Descente du St Esprit (de Vin)
+v Dilution
+4 Ste Pure, sportswoman
+v Vide
+4 St Canterel, l'illuminateur
+4 St Sophrotatos l'Armnien, pataphysicien
+3 thernit
+4 St Ibicrate le Gomtre, pataphysicien
+v Cphalorgie
+v Fltes de Pan
+4 Stes Grues, ophiophiles
+4 Ste Mlusine, souillarde de cuisine
+4 St Venceslas, duc
+2 Emmanuel Dieu
+4 Ste Varia-Miriam, amphibie
+4 Sts Rakirs et Rastrons, porte-ctelettes
+4 Nativit de Sa Magnificence Opach
+4 St Joseb, notaire  la mode de Bretagne
+4 Stes Gigolette et Gaufrette, dogaresses
+v Xylostomie
+v Le Jet Musical
 
-L'ge du Dr Faustroll
-Dissolution d'E. Poe, dinomythurge
-St Gibus, franc-maon
-Ste Berthe de Courrire, grie
-Ste Belgique, nourrice
-Ste Tourte, lyrique et Ste Bvue, sociologue
-St Prout, abb
-Fte du Haha
-Tautologie
-St Panmuphle, huissier
-Sortie de St L. Cranach, apocalypticien
-St Cosinus, savant
-Bse Fenouillard, sainte famille
-Exhibition de la Daromphe
-Nativit de l'OEstre, artificier
-Ste Vadrouille, emblme
-St Homais d'Aquin, prudhomme
-Nativit de Sa Magnificence le baron Mollet (St Pipe)
-St Raphal, apritif et philistin
-Strangulation de Bosse-de-Nage
-Zimzoum de Bosse-de-Nage
-Rsurrection de Bosse-de-Nage
-Chapeau de Bosse-de-Nage
-St Cl. Terrasse, musicien des Phynances
-St J.-P. Brisset, philologue, prince des penseurs
-Commmoration du Cure-dent
-Occultation d'Alfred Jarry
-Fuite d'Ablou
-Mare Terrestre
+2 L'ge du Dr Faustroll
+4 Dissolution d'E. Poe, dinomythurge
+4 St Gibus, franc-maon
+4 Ste Berthe de Courrire, grie
+4 Ste Belgique, nourrice
+4 Ste Tourte, lyrique et Ste Bvue, sociologue
+4 St Prout, abb
+2 Fte du Haha
+v Tautologie
+4 St Panmuphle, huissier
+4 Sortie de St L. Cranach, apocalypticien
+4 St Cosinus, savant
+4 Bse Fenouillard, sainte famille
+4 Exhibition de la Daromphe
+3 Nativit de l'OEstre, artificier
+4 Ste Vadrouille, emblme
+4 St Homais d'Aquin, prudhomme
+4 Nativit de Sa Magnificence le baron Mollet (St Pipe)
+4 St Raphal, apritif et philistin
+3 Strangulation de Bosse-de-Nage
+3 Zimzoum de Bosse-de-Nage
+2 Rsurrection de Bosse-de-Nage
+3 Chapeau de Bosse-de-Nage
+4 St Cl. Terrasse, musicien des Phynances
+4 St J.-P. Brisset, philologue, prince des penseurs
+4 Commmoration du Cure-dent
+1 Occultation d'Alfred Jarry
+4 Fuite d'Ablou
+v Mare Terrestre
 
-Nativit de Pantagruel
-Ste Rrose Slavy, hrone
-Couronnement de Lord Patchogue, miroitier
-St Cravan, boxeur
-St Van Meegeren, faussaire
-St Omnibus, satyre
-St Cyrano de Bergerac, explorateur
-St Rimbe, oisif
-quarrissage pour tous
-St Abstrait, bourreau
-St Ossian, barde postiche
-Dispute du Signe + et du Signe -
-Moustaches du Dr Faustroll
-St P. Bonnard, peintre des Phynances
-Navigation du Dr Faustroll
-St Cap, captain
-St Pangloss, humoriste passif
-St Chambernac, pauvriseur
-St Courtial des Preires, arostier et inventeur
-St Olibrius, augure
-St Possible, schizophrne
-St Lautramont
-St Quincey, critique d'art
-St Berbiguier, martyr
-St Lewis Carroll, professeur
-St Mensonger, vque
-Ste Visit, fille du prcdent
-Nativit de St Swift, chanoine
-Traverse du Miroir
+3 Nativit de Pantagruel
+4 Ste Rrose Slavy, hrone
+4 Couronnement de Lord Patchogue, miroitier
+4 St Cravan, boxeur
+4 St Van Meegeren, faussaire
+4 St Omnibus, satyre
+4 St Cyrano de Bergerac, explorateur
+3 St Rimbe, oisif
+v quarrissage pour tous
+4 St Abstrait, bourreau
+4 St Ossian, barde postiche
+3 Dispute du Signe + et du Signe -
+3 Moustaches du Dr Faustroll
+4 St P. Bonnard, peintre des Phynances
+1 Navigation du Dr Faustroll
+4 St Cap, captain
+4 St Pangloss, humoriste passif
+4 St Chambernac, pauvriseur
+4 St Courtial des Preires, arostier et inventeur
+4 St Olibrius, augure
+4 St Possible, schizophrne
+2 St Lautramont
+4 St Quincey, critique d'art
+4 St Berbiguier, martyr
+4 St Lewis Carroll, professeur
+4 St Mensonger, vque
+4 Ste Visit, fille du prcdent
+4 Nativit de St Swift, chanoine
+v Traverse du Miroir
 
-Noces de Balkis et de Salomon
-St Doublemain, idologue
-St Phlegmon, doctrinaire
-Ste Barbe (femme ), femme-canon
-Ste Savate, avocate
-St Navet et Ste Perruque, humanistes
-St Birbe, juge
-Conception du P. Ubu (A. J.)
-St Sagouin, homme d'tat
-Exaltation d'Ubu Roi (Ubu d'hiver)
-Nativit de St Grabbe, scherziste
-Ste Choupe, mre de famille
-St Flaive, concierge
-Don Quichotte, champion du monde
-Khurmookum du Dr Faustroll
-St Nul, exempt
-St Moyen, franais
-Ste Lurette, joconde
-Gravidit de Mre Ubu
-St Sabre, allopathe
-Ste Tape, pompette
-Csar - Antechrist
-Ste Viole, vierge et martyre
-Ste Pochete, gouvernante
-Nativit de l'Archoptryx
-Monsieur Sisyphe
-St Tic, conjoint
-St Cervelas, penseur
-Aleph
+3 Noces de Balkis et de Salomon
+4 St Doublemain, idologue
+4 St Phlegmon, doctrinaire
+4 Ste Barbe (femme ), femme-canon
+4 Ste Savate, avocate
+4 St Navet et Ste Perruque, humanistes
+4 St Birbe, juge
+2 Conception du P. Ubu (A. J.)
+4 St Sagouin, homme d'tat
+1 Exaltation d'Ubu Roi (Ubu d'hiver)
+4 Nativit de St Grabbe, scherziste
+4 Ste Choupe, mre de famille
+4 St Flaive, concierge
+4 Don Quichotte, champion du monde
+2 Khurmookum du Dr Faustroll
+4 St Nul, exempt
+4 St Moyen, franais
+4 Ste Lurette, joconde
+3 Gravidit de Mre Ubu
+4 St Sabre, allopathe
+4 Ste Tape, pompette
+1 Csar - Antechrist
+4 Ste Viole, vierge et martyre
+4 Ste Pochete, gouvernante
+3 Nativit de l'Archoptryx
+4 Monsieur Sisyphe
+4 St Tic, conjoint
+4 St Cervelas, penseur
+v Aleph
 
-St Alaodine, virtuose
-Sts Hassassins, praticiens
-Astu
-Dcervelage
-Sts Giron, Pile et Cotice, palotins
-Sts Polonais, proltaires
-Sts Forats, poliorctes
-St Bordure, capitaine
-Dormition de Jacques Vach, interprte
-Drapaud (rection du)
-St Eustache, librateur
-St Landru, gyncologue
-St Guillotin, mdecin
-Sts 4 Sans-Cou, enchanteurs
-Conscience d'Ubu
-St Mauvais, sujet
-St Mandrin, pote et philosophe
-Sts Pirates et Flibustiers, thaumaturges
-St et Ste Cartouche, vtrinaires
-St Outlaw, aristocrate
-Chaire du Dr FaustrolL
-Ostention du Bton  Physique
-St Tank, animal
-St Weidman, patriarche
-St Petiot, expert
-Escrime
-Sts Chemins de fer, assassins
-Repopulation
-Lit de Procruste
+3 St Alaodine, virtuose
+4 Sts Hassassins, praticiens
+4 Astu
+1 Dcervelage
+4 Sts Giron, Pile et Cotice, palotins
+4 Sts Polonais, proltaires
+4 Sts Forats, poliorctes
+3 St Bordure, capitaine
+4 Dormition de Jacques Vach, interprte
+v Drapaud (rection du)
+4 St Eustache, librateur
+4 St Landru, gyncologue
+4 St Guillotin, mdecin
+4 Sts 4 Sans-Cou, enchanteurs
+3 Conscience d'Ubu
+4 St Mauvais, sujet
+4 St Mandrin, pote et philosophe
+4 Sts Pirates et Flibustiers, thaumaturges
+4 St et Ste Cartouche, vtrinaires
+4 St Outlaw, aristocrate
+1 Chaire du Dr FaustrolL
+2 Ostention du Bton  Physique
+4 St Tank, animal
+4 St Weidman, patriarche
+4 St Petiot, expert
+v Escrime
+4 Sts Chemins de fer, assassins
+v Repopulation
+v Lit de Procruste
 
-Dpucelage de Mre Ubu
-St Sigisbe, eunuque
-St Anthropode, policier
-Ste Goule ou Gudule, institutrice
-Ste Gale, abbesse
-Ste Touche, postulante
-St Gueule, abb
-Fte de la Chandelle Verte
-Ste Crpe, laque
-St Prservatif, bedeau
-St Baobab, clibataire
-St Membre, compilateur
-Copulation
-Nativit de St J. Verne, globe-trotter en chambre
-Alice au Pays des Merveilles
-St Mnchhausen, baron
-Le Btrou, thurge
-Nativit de St Deibler, prestidigitateur
-St Sade s liens
-St Lafleur, valet
-Lavement
-St Sexe, stylite
-Occultation de St J. Torma, euphoriste
-Conversion de St Matorel, bateleur
-Ste Marmelade, inspire
-L'Amour Absolu, deliquium
-Ste Tabagie, cosmogne
-Sts Hylactor et Pamphagus
-Mouvement Perptuel
+3 Dpucelage de Mre Ubu
+4 St Sigisbe, eunuque
+4 St Anthropode, policier
+4 Ste Goule ou Gudule, institutrice
+4 Ste Gale, abbesse
+4 Ste Touche, postulante
+4 St Gueule, abb
+3 Fte de la Chandelle Verte
+4 Ste Crpe, laque
+4 St Prservatif, bedeau
+4 St Baobab, clibataire
+4 St Membre, compilateur
+v Copulation
+4 Nativit de St J. Verne, globe-trotter en chambre
+v Alice au Pays des Merveilles
+4 St Mnchhausen, baron
+4 Le Btrou, thurge
+4 Nativit de St Deibler, prestidigitateur
+4 St Sade s liens
+4 St Lafleur, valet
+v Lavement
+2 St Sexe, stylite
+4 Occultation de St J. Torma, euphoriste
+4 Conversion de St Matorel, bateleur
+4 Ste Marmelade, inspire
+3 L'Amour Absolu, deliquium
+4 Ste Tabagie, cosmogne
+4 Sts Hylactor et Pamphagus
+v Mouvement Perptuel
 
-rection du Surmle
-St Andr Marcueil, ascte cycliste
-St Ellen, hile
-St Michet, idaliste
-St Ouducul, trouvre
-Vers Belges
-St Gavroche, forain
-La Machine  Inspirer l'Amour
-St Remezy, vque in partibus
-Nativit de St Tancrde, jeune homme
-Testament de P. Uccello, le mal illumin
-St Hari Seldon, psychohistorien galactique
-Ste Valburge, succube
-Sabbat
-Sts Adelphes, sotristes
-Sts Templiers, adeptes
-St Dricarpe, proslyte
-St Nosocome, carabin
-Ste Goutte, fte militaire
-Ste Cuisse, dame patronnesse
-St Inscrit, Converti
-St Sengle, dserteur
-St Masquarade, uniforme
-Nativit de St Stphane, faune
-St Poligraf Poligrafovitch, chien
-St Ple, mineur
-St Valens, frre onirique
-Ddicace du Tripode
-Bse Escampette, dynamiteuse
+3 rection du Surmle
+4 St Andr Marcueil, ascte cycliste
+4 St Ellen, hile
+4 St Michet, idaliste
+4 St Ouducul, trouvre
+4 Vers Belges
+4 St Gavroche, forain
+3 La Machine  Inspirer l'Amour
+4 St Remezy, vque in partibus
+4 Nativit de St Tancrde, jeune homme
+4 Testament de P. Uccello, le mal illumin
+4 St Hari Seldon, psychohistorien galactique
+4 Ste Valburge, succube
+v Sabbat
+3 Sts Adelphes, sotristes
+4 Sts Templiers, adeptes
+4 St Dricarpe, proslyte
+4 St Nosocome, carabin
+4 Ste Goutte, fte militaire
+4 Ste Cuisse, dame patronnesse
+4 St Inscrit, Converti
+2 St Sengle, dserteur
+4 St Masquarade, uniforme
+4 Nativit de St Stphane, faune
+4 St Poligraf Poligrafovitch, chien
+4 St Ple, mineur
+3 St Valens, frre onirique
+v Ddicace du Tripode
+4 Bse Escampette, dynamiteuse
 
-St Ablou, page et St Haldern, duc
-Sts Hiboux, matres-chanteurs
-La Mandragore, solane androde
-St Pagne, confident
-Sts Aster et Vulpian, violateurs du Nant
-St Ganymde, professionnel
-La Main de Gloire
-La Machine  Peindre
-Ste Trique, lunatique
-Rmission des Poissons
-St Maquereau, intercesseur
-St Georges Dazet, poulpe au regard de soie
-Nativit de Maldoror, corsaire aux cheveux d'or
-Sortie d'A. Drer, hermtiste
-Invention de la 'Pataphysique
-Exit St Domenico Theotocopouli, el Greco
-St Hironymus Bosch, dmonarque
-Les 27 tres Issus des Livres Pairs
-St Barbeau, procureur et Ste Morue, juste
-Capture du Fourneau
-St Docteur Moreau, insulaire
-Fte des Polydres
-Locus Solus
-St Tupetu de Tupetu, organisateur de loteries
-Exit St Goya, alchimiste
-St Escargot, sybarite
-Ste Hure de Chastet, pnitente
-St Turgescent, iconoclaste
-Cymbalum Mundi
+3 St Ablou, page et St Haldern, duc
+4 Sts Hiboux, matres-chanteurs
+4 La Mandragore, solane androde
+4 St Pagne, confident
+4 Sts Aster et Vulpian, violateurs du Nant
+4 St Ganymde, professionnel
+v La Main de Gloire
+3 La Machine  Peindre
+4 Ste Trique, lunatique
+4 Rmission des Poissons
+4 St Maquereau, intercesseur
+4 St Georges Dazet, poulpe au regard de soie
+4 Nativit de Maldoror, corsaire aux cheveux d'or
+4 Sortie d'A. Drer, hermtiste
+* Invention de la 'Pataphysique
+4 Exit St Domenico Theotocopouli, el Greco
+4 St Hironymus Bosch, dmonarque
+v Les 27 tres Issus des Livres Pairs
+4 St Barbeau, procureur et Ste Morue, juste
+v Capture du Fourneau
+4 St Docteur Moreau, insulaire
+2 Fte des Polydres
+v Locus Solus
+4 St Tupetu de Tupetu, organisateur de loteries
+4 Exit St Goya, alchimiste
+4 St Escargot, sybarite
+4 Ste Hure de Chastet, pnitente
+4 St Turgescent, iconoclaste
+v Cymbalum Mundi
 
-Sts Crocodiles, crocodiles
-Fte des cluses
-Sts Trolls, pantins
-Ste Susan Calvin, docteur
-Ste Poigne, veuve et Ste Jutte, recluse
-Ste Oneille, gourgandine
-St Fnon s Liens
-St Bougrelas, prince
-Sts Boleslas et Ladislas, polonais
-St Forficule, Barnabite
-Explosion du Palotin
-Rprobation du Travail
-Esquive de St Lonard (de Vinci), illusionniste
-St quivoque, sans-culotte
-Adoration du Pal
-Dploration de St Achras, leveur de Polydres
-St Macrotatoure, caudataire
-Canotage
-Occultation de St Gauguin, ocanide
-St Ti Belot, side
-Occultation de Sa Magnificence le Dr Sandomir
-Sts Palotins des Phynances
-Sts Quatrezoneilles, Herdanpo, Mousched-Gogh, palotins
-Ste Lumelle, cuyre
-Sts Potassons, acolythes
-Ste Prtentaine, rosire
-St Foin, coryphe
-Nativit de St Satie, Grand Parcier de l'glise d'Art
-Erratum
+3 Sts Crocodiles, crocodiles
+4 Fte des cluses
+4 Sts Trolls, pantins
+4 Ste Susan Calvin, docteur
+4 Ste Poigne, veuve et Ste Jutte, recluse
+4 Ste Oneille, gourgandine
+4 St Fnon s Liens
+3 St Bougrelas, prince
+4 Sts Boleslas et Ladislas, polonais
+4 St Forficule, Barnabite
+v Explosion du Palotin
+v Rprobation du Travail
+4 Esquive de St Lonard (de Vinci), illusionniste
+4 St quivoque, sans-culotte
+3 Adoration du Pal
+4 Dploration de St Achras, leveur de Polydres
+4 St Macrotatoure, caudataire
+v Canotage
+4 Occultation de St Gauguin, ocanide
+4 St Ti Belot, side
+4 Occultation de Sa Magnificence le Dr Sandomir
+2 Sts Palotins des Phynances
+4 Sts Quatrezoneilles, Herdanpo, Mousched-Gogh, palotins
+4 Ste Lumelle, cuyre
+4 Sts Potassons, acolythes
+4 Ste Prtentaine, rosire
+4 St Foin, coryphe
+4 Nativit de St Satie, Grand Parcier de l'glise d'Art
+v Erratum
 
-Accouchement de Ste Jeanne, papesse
-Le Moutardier du Pape
-St Sige, sous-pape
-Nativit de St H. Rousseau, douanier
-St Crouducul, troupier
-St Cucufat, mcne
-Nativit de M. Plume, propritaire
-Cocuage de M. le P. Ubu
-Vidange
-St Barbapoux, amant
-St Memnon, vidangeur
-Stes Miches, catchumnes
-Ste Lunette, solitaire
-St Sphincter, profs
-Sts Serpents d'Airain
-Nativit de St Donatien A. Franois
-St Woland, professeur
-St Anal, cordelier et Ste Foire, anagogue
-Ste Ftatoire, super
-Ste Colombine, expurge
-Ste Pyrotechnie, illumine
-Ontognie Pataphysique
-Interprtation de L'Umour
-Ste Purge, sage-femme
-Apparition D'Ubu Roi
-Ste Barbaque, naade
-Sts Courts et Longs, gendarmes
-St Raca, cagot
-Dfaite du Mufle
+3 Accouchement de Ste Jeanne, papesse
+v Le Moutardier du Pape
+4 St Sige, sous-pape
+4 Nativit de St H. Rousseau, douanier
+4 St Crouducul, troupier
+4 St Cucufat, mcne
+4 Nativit de M. Plume, propritaire
+2 Cocuage de M. le P. Ubu
+v Vidange
+4 St Barbapoux, amant
+4 St Memnon, vidangeur
+4 Stes Miches, catchumnes
+4 Ste Lunette, solitaire
+4 St Sphincter, profs
+3 Sts Serpents d'Airain
+4 Nativit de St Donatien A. Franois
+4 St Woland, professeur
+4 St Anal, cordelier et Ste Foire, anagogue
+4 Ste Ftatoire, super
+4 Ste Colombine, expurge
+4 Ste Pyrotechnie, illumine
+* Ontognie Pataphysique
+3 Interprtation de L'Umour
+4 Ste Purge, sage-femme
+2 Apparition D'Ubu Roi
+4 Ste Barbaque, naade
+4 Sts Courts et Longs, gendarmes
+4 St Raca, cagot
+v Dfaite du Mufle
 
-Ste Bouzine, esprit
-St Lucullus, amateur (Bloomsday)
-Ste Dondon, amazone
-Ste Tripe, rpublicaine
-St Ugolin, mansuet
-St Dieu, retrait
-St Bb Toutout, vangliste
-Ste Boudouille, bayadre
-Ste Outre, psychiatre
-St Boudin, recteur
-Sacre de Talou VII, empereur du Ponukl
-Ste Confiture, dvote et Ste Cliche, donatrice
-Sts Instintestins, conseillers intimes
-St Colon, artilleur
-Ste Giborgne, vnrable
-St Inventaire, pote
-Ste Femelle, technicienne
-Visitation de Mre Ubu
-St Sein, tautologue
-St Prine, zlateur
-St Spculum, confesseur
-Fte de Gidouille
-St Ombilic, gymnosophiste
-St Gris-gris, ventre
-St Bouffre, pontife
-Ste Goulache, odalisque
-Ste Gandouse, hyginiste
-Poche du Pre Ubu
-Nom d'Ubu
+3 Ste Bouzine, esprit
+4 St Lucullus, amateur (Bloomsday)
+4 Ste Dondon, amazone
+4 Ste Tripe, rpublicaine
+4 St Ugolin, mansuet
+4 St Dieu, retrait
+4 St Bb Toutout, vangliste
+3 Ste Boudouille, bayadre
+4 Ste Outre, psychiatre
+4 St Boudin, recteur
+4 Sacre de Talou VII, empereur du Ponukl
+4 Ste Confiture, dvote et Ste Cliche, donatrice
+4 Sts Instintestins, conseillers intimes
+4 St Colon, artilleur
+3 Ste Giborgne, vnrable
+4 St Inventaire, pote
+4 Ste Femelle, technicienne
+2 Visitation de Mre Ubu
+4 St Sein, tautologue
+4 St Prine, zlateur
+4 St Spculum, confesseur
+2 Fte de Gidouille
+4 St Ombilic, gymnosophiste
+4 St Gris-gris, ventre
+4 St Bouffre, pontife
+4 Ste Goulache, odalisque
+4 Ste Gandouse, hyginiste
+v Poche du Pre Ubu
+2 Nom d'Ubu
 
-Fte du P. Ubu (Ubu d't)
-Commmoration du P. b
-Ste Crapule, puriste et St Fantomas, archange
-Ascension du Mouchard, statisticien, psychiatre et policier
-St Arsouille, patricien
-Sts Robot et Cornard, citoyens
-St Biribi, taulier
-Susception du Croc  Merdre
-Sts crase-Merdre, sectateurs
-Sts Pieds Nickels, trinit
-Stes Canicule et Canule, jouvencelles
-Sts Cannibales, philanthropes
-St Dada, prophte
-Ste Anne, plerine, nergumne
-Procession aux Phynances
-Transfiguration de St V. van Gogh, transmutateur
-Ste Flamberge, voyante
-St Trou, chauffeur
-Ste Taloche, matrone
-St Tiberge, frre quteur
-Sts Catoblepas, lord et Anoblepas, amiral
-Ubu s Liens
-St Pissembock, oncle
-St Pissedoux, caporal des hommes libres
-St Panurge, moraliste
-St Gl, neurologue-aliniste
-St Pistolet  Merdre, jubilaire
-Nativit de St Bruggle
-Le soleil solide froid
+1 Fte du P. Ubu (Ubu d't)
+4 Commmoration du P. b
+4 Ste Crapule, puriste et St Fantomas, archange
+4 Ascension du Mouchard, statisticien, psychiatre et policier
+4 St Arsouille, patricien
+4 Sts Robot et Cornard, citoyens
+4 St Biribi, taulier
+2 Susception du Croc  Merdre
+4 Sts crase-Merdre, sectateurs
+4 Sts Pieds Nickels, trinit
+4 Stes Canicule et Canule, jouvencelles
+4 Sts Cannibales, philanthropes
+4 St Dada, prophte
+4 Ste Anne, plerine, nergumne
+2 Procession aux Phynances
+4 Transfiguration de St V. van Gogh, transmutateur
+4 Ste Flamberge, voyante
+4 St Trou, chauffeur
+4 Ste Taloche, matrone
+4 St Tiberge, frre quteur
+4 Sts Catoblepas, lord et Anoblepas, amiral
+2 Ubu s Liens
+4 St Pissembock, oncle
+4 St Pissedoux, caporal des hommes libres
+4 St Panurge, moraliste
+4 St Gl, neurologue-aliniste
+4 St Pistolet  Merdre, jubilaire
+4 Nativit de St Bruggle
+v Le soleil solide froid
 
-St Chibre, planton
-Ste Ruth, zlatrice
-St Zebb, passe-partout
-St Mnester, confesseur
-Assomption de Ste Messaline
-Penis Angelicus
-St Patrobas, pompier
-Ste Lda, ajusteuse
-St Godemich, conome
-Ste Nitouche, orante
-Ste Lchefrite, botteuse
-Ste Andouille, amphibologue
-Ste Bitre, ouvreuse et St talon, couvreur
-Bataille de Morsang
-Mort de Dionysos, surhomme
-Nativit de St Vibescu, pohte et Commmoration de Ste Cuculine d'Ancne
-Ste Gallinace, cocotte
-St Lingam, bouche-trou
-St Prlote, capucin
-St Pie VIII, navigant
-St Erbrand, polytechnicien
-Ste Dragonne, pyrophage
-St Lazare, gare
-Ste Orchide, aumonire
-Nativit apparente d'Artaud le Momo
-Disparition de l'Ancien Breughel, incendiaire
-St Priape, franc-tireur
-Transfixion de Ste Messaline
-Le Terms
+3 St Chibre, planton
+4 Ste Ruth, zlatrice
+4 St Zebb, passe-partout
+4 St Mnester, confesseur
+2 Assomption de Ste Messaline
+v Penis Angelicus
+4 St Patrobas, pompier
+3 Ste Lda, ajusteuse
+4 St Godemich, conome
+4 Ste Nitouche, orante
+4 Ste Lchefrite, botteuse
+4 Ste Andouille, amphibologue
+4 Ste Bitre, ouvreuse et St talon, couvreur
+3 Bataille de Morsang
+3 Mort de Dionysos, surhomme
+4 Nativit de St Vibescu, pohte et Commmoration de Ste Cuculine d'Ancne
+4 Ste Gallinace, cocotte
+4 St Lingam, bouche-trou
+4 St Prlote, capucin
+4 St Pie VIII, navigant
+3 St Erbrand, polytechnicien
+2 Ste Dragonne, pyrophage
+4 St Lazare, gare
+4 Ste Orchide, aumonire
+4 Nativit apparente d'Artaud le Momo
+4 Disparition de l'Ancien Breughel, incendiaire
+4 St Priape, franc-tireur
+3 Transfixion de Ste Messaline
+v Le Terms
 EOF
 
 1;
@@ -1075,6 +1093,17 @@ additional specifier: C<%*> represents the feast of that date.
 
 Returns the feast or vacuation of the given date.
 
+=item * type_of_feast
+
+Returns the type of feast or vacuation.
+
+  '*' means Fte Suprme Premire premire
+  '1' means Fte Suprme Premire seconde
+  '2' means Fte Suprme Seconde
+  '3' means Fte Suprme Tierce
+  '4' means Fte Suprme Quarte
+  'v' means Vacuation
+
 =item * is_imaginary
 
 Returns true or false indicating whether the datetime object represents an
@@ -1160,9 +1189,9 @@ Eugene van der Pijll <pijll@gmx.net>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 Eugene van der Pijll.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+Copyright (c) 2003, 2004 Eugene van der Pijll.  All rights reserved.
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
